summaryrefslogtreecommitdiffstats
path: root/src/plugins/platforms/wasm
diff options
context:
space:
mode:
authorLorn Potter <lorn.potter@gmail.com>2023-11-28 11:20:15 +1000
committerLorn Potter <lorn.potter@gmail.com>2023-12-08 09:22:33 +1000
commitd784c14d101ebb1c357cf3096d99e7e9be274931 (patch)
treebc9de6f90b7d8aab6385539824cbc60591077e8d /src/plugins/platforms/wasm
parenta5bcb41678ad7fe78ad3fac066094f6a614b6906 (diff)
wasm: prevent native mobile keyboard from popping up always
also fix misspelled 'inputMode' which seems to work. we need to re focus to the canvas when window is raised which will automagically close the native keyboard when user clicks on non edit area. Fixes: QTBUG-101404 Pick-to: 6.6 6.5 Change-Id: Iced9abc7b23e079b1060d2474a139aa653a8ca01 Reviewed-by: Morten Johan Sørvig <morten.sorvig@qt.io> Reviewed-by: Piotr Wierciński <piotr.wiercinski@qt.io>
Diffstat (limited to 'src/plugins/platforms/wasm')
-rw-r--r--src/plugins/platforms/wasm/qwasmwindow.cpp6
1 files changed, 4 insertions, 2 deletions
diff --git a/src/plugins/platforms/wasm/qwasmwindow.cpp b/src/plugins/platforms/wasm/qwasmwindow.cpp
index c9e88da245..11ce724b01 100644
--- a/src/plugins/platforms/wasm/qwasmwindow.cpp
+++ b/src/plugins/platforms/wasm/qwasmwindow.cpp
@@ -80,9 +80,9 @@ QWasmWindow::QWasmWindow(QWindow *w, QWasmDeadKeySupport *deadKeySupport,
QWasmClipboard::installEventHandlers(m_canvas);
// set inputmode to none to stop mobile keyboard opening
// when user clicks anywhere on the canvas.
- m_canvas.set("inputmode", std::string("none"));
+ m_canvas.set("inputMode", std::string("none"));
// Hide the canvas from screen readers.
m_canvas.call<void>("setAttribute", std::string("aria-hidden"), std::string("true"));
@@ -362,6 +362,8 @@ void QWasmWindow::raise()
{
bringToTop();
invalidate();
+ if (QWasmIntegration::get()->inputContext())
+ m_canvas.call<void>("focus");
}
void QWasmWindow::lower()
@@ -80,9 +80,9 @@ QWasmWindow::QWasmWindow(QWindow *w, QWasmDeadKeySupport *deadKeySupport,
QWasmClipboard::installEventHandlers(m_canvas);
- // set inputmode to none to stop mobile keyboard opening
+ // set inputMode to none to stop mobile keyboard opening
// when user clicks anywhere on the canvas.